@@ -37,13 +37,7 @@ class Test_DB_Mysqli extends Test_DB_Test
   
   public function testInit()
   {
-    $params = array("package"  => "sabel.db.mysqli",
-                    "host"     => "127.0.0.1",
-                    "user"     => "root",
-                    "password" => "",
-                    "database" => "sdb_test");
-    
-    Sabel_DB_Config::add("default", $params);
+    Sabel_DB_Config::add("default", Test_DB_TestConfig::getMysqliConfig());
     Test_DB_Test::$db = "MYSQL";
   }
 }
