@@ -116,18 +116,20 @@ class Test_Util_FileSystem extends SabelTestCase
   
   public function testFilePermission()
   {
+    // win
     if (DIRECTORY_SEPARATOR === "\\") return;
     
     $file = "hoge" . DS . "fuga" . DS . "foo.txt";
     $fs = new Sabel_Util_FileSystem($this->basedir . DS . "test");
     $file = $fs->getFile($file);
-    $this->assertEquals(0744, $file->getPermission());
+    $this->assertEquals(0755, $file->getPermission());
     $file->chmod(0777);
     $this->assertEquals(0777, $file->getPermission());
   }
   
   public function testFilePermission2()
   {
+    // win
     if (DIRECTORY_SEPARATOR === "\\") return;
     
     chmod($this->basedir . DS . "readable.txt", 0444);
@@ -158,13 +160,14 @@ class Test_Util_FileSystem extends SabelTestCase
   
   public function testDirectoryPermission()
   {
+    // win
     if (DIRECTORY_SEPARATOR === "\\") return;
     
     $fs = new Sabel_Util_FileSystem($this->basedir . DS . "test");
     $dir = $fs->getDirectory("hoge" . DS . "fuga");
-    $this->assertEquals(0744, $dir->getPermission());
-    $dir->chmod(0755);
     $this->assertEquals(0755, $dir->getPermission());
+    $dir->chmod(0777);
+    $this->assertEquals(0777, $dir->getPermission());
   }
   
   public function testFileSize()
@@ -214,12 +217,12 @@ class Test_Util_FileSystem extends SabelTestCase
   {
     $fs = new Sabel_Util_FileSystem($this->basedir . DS . "test" . DS . "hoge" . DS . "fuga");
     $file = $fs->getFile("foo.txt");
-    $file->copy(".." . DS . "test" . DS . "foo2.txt", true);
+    $file->copyTo(".." . DS . "test" . DS . "foo2.txt");
     
     $fs->cd(".." . DS . "test");
     $this->assertTrue($fs->isFile("foo2.txt"));
     
-    $file->copy(".." . DS . "test");
+    $file->copyTo(".." . DS . "test" . DS . "foo.txt");
     $this->assertTrue($fs->isFile("foo.txt"));
   }
   
@@ -227,13 +230,13 @@ class Test_Util_FileSystem extends SabelTestCase
   {
     $fs = new Sabel_Util_FileSystem($this->basedir . DS . "test");
     $file = $fs->getFile("hoge" . DS . "test" . DS . "foo2.txt");
-    $moved = $file->move(".." . DS . "test2");
+    $moved = $file->moveTo(".." . DS . "test2" . DS . "foo2.txt");
     
     $fs->cd(".." . DS . "test" . DS . "hoge");
     $this->assertTrue($fs->isFile("test2" . DS . "foo2.txt"));
     $this->assertFalse($fs->isFile("hoge" . DS . "foo2.txt"));
     
-    $moved->move("foo3.txt", true);
+    $moved->moveTo("foo3.txt");
     $this->assertTrue($fs->isFile("test2" . DS . "foo3.txt"));
     $this->assertFalse($fs->isFile("test2" . DS . "foo2.txt"));
   }
@@ -264,7 +267,7 @@ class Test_Util_FileSystem extends SabelTestCase
     $fs = new Sabel_Util_FileSystem($this->basedir . DS . "test");
     $this->assertFalse($fs->isDir("moved"));
     
-    $fs->copy("moved");
+    $fs->copyTo(".." . DS . "moved");
     $fs->cd("..");
     $this->assertTrue($fs->isDir("moved"));
     $fs->cd("moved");
