@@ -18,6 +18,8 @@ abstract class Sabel_DB_Statement extends Sabel_Object
   const DELETE = 0x08;
   const QUERY  = 0x10;
   
+  const BINARY_IDENTIFIER = "__SBL_BINARY";
+  
   /**
    * @var array
    */
@@ -48,6 +50,11 @@ abstract class Sabel_DB_Statement extends Sabel_Object
    */
   protected $bindValues = array();
   
+  /**
+   * @var array
+   */
+  protected $binaries = array();
+  
   /**
    * @var string
    */
@@ -88,6 +95,16 @@ abstract class Sabel_DB_Statement extends Sabel_Object
    */
   protected $forUpdate = false;
   
+  /**
+   * @param string $binaryData
+   *
+   * @return Sabel_DB_Abstract_Blob
+   */
+  abstract public function createBlob($binaryData);
+  
+  /**
+   * @return array
+   */
   public static function getExecutedQueries()
   {
     return self::$queries;
@@ -121,6 +138,7 @@ abstract class Sabel_DB_Statement extends Sabel_Object
   {
     $this->query       = "";
     $this->bindValues  = array();
+    $this->binaries    = array();
     $this->projection  = array();
     $this->join        = "";
     $this->where       = "";
@@ -132,7 +150,7 @@ abstract class Sabel_DB_Statement extends Sabel_Object
     return $this;
   }
   
-  public function type($type = null)
+  public function type($type)
   {
     $this->type = $type;
     
@@ -206,7 +224,16 @@ abstract class Sabel_DB_Statement extends Sabel_Object
   
   public function values(array $values)
   {
-    $this->values = $this->bindValues = $values;
+    $columns = $this->metadata->getColumns();
+    foreach ($values as $k => &$v) {
+      if (isset($columns[$k]) && $columns[$k]->isBinary()) {
+        $this->binaries[] = $this->createBlob($v);
+        $v = new Sabel_DB_Statement_Expression($this, self::BINARY_IDENTIFIER . count($this->binaries));
+      }
+    }
+    
+    $this->values = $values;
+    $this->appendBindValues($values);
     
     return $this;
   }
@@ -235,7 +262,7 @@ abstract class Sabel_DB_Statement extends Sabel_Object
     }
   }
   
-  public function execute($bindValues = array())
+  public function execute($bindValues = array(), $additionalParameters = array())
   {
     $query = $this->getQuery();
     
@@ -251,8 +278,16 @@ abstract class Sabel_DB_Statement extends Sabel_Object
       }
     }
     
+    if (!empty($this->binaries)) {
+      for ($i = 0, $c = count($this->binaries); $i < $c; $i++) {
+        $query = str_replace(self::BINARY_IDENTIFIER . ($i + 1),
+                             $this->binaries[$i]->getData(),
+                             $query);
+      }
+    }
+    
     $start  = microtime(true);
-    $result = $this->driver->execute($query, $bindValues);
+    $result = $this->driver->execute($query, $bindValues, $additionalParameters);
     
     self::$queries[] = array("sql"   => $query,
                              "time"  => microtime(true) - $start,
@@ -281,9 +316,11 @@ abstract class Sabel_DB_Statement extends Sabel_Object
     return $this;
   }
   
-  public function getBindValues()
+  public function appendBindValues(array $values)
   {
-    return $this->bindValues;
+    $this->bindValues = array_merge($this->bindValues, $values);
+    
+    return $this;
   }
   
   public function isSelect()
@@ -306,25 +343,12 @@ abstract class Sabel_DB_Statement extends Sabel_Object
     return ($this->type === Sabel_DB_Statement::DELETE);
   }
   
-  public function quoteIdentifier($arg)
-  {
-    if (is_array($arg)) {
-      foreach ($arg as &$v) {
-        $v = '"' . $v . '"';
-      }
-      return $arg;
-    } elseif (is_string($arg)) {
-      return '"' . $arg . '"';
-    } else {
-      $message = "argument must be a string or an array.";
-      throw new Sabel_Exception_InvalidArgument($message);
-    }
-  }
-  
   public function build()
   {
     if ($this->metadata === null) {
-      $message = "can't build sql query. must set the metadata with setMetadata().";
+      $message = __METHOD__ . "() can't build sql query. "
+               . "must set the metadata with setMetadata().";
+      
       throw new Sabel_Exception_Runtime($message);
     }
     
@@ -363,13 +387,21 @@ abstract class Sabel_DB_Statement extends Sabel_Object
   
   protected function createInsertSql()
   {
-    $sql  = "INSERT INTO {$this->quoteIdentifier($this->table)} (";
-    $cols = array_keys($this->values);
-    
+    $sql  = "INSERT INTO " . $this->quoteIdentifier($this->table) . " (";
+    $cols = array();
     $hlds = array();
-    foreach ($cols as $c) $hlds[] = "@{$c}@";
     
-    $cols = $this->quoteIdentifier($cols);
+    foreach ($this->values as $column => $value) {
+      $cols[] = $this->quoteIdentifier($column);
+      
+      if ($value instanceof Sabel_DB_Statement_Expression) {
+        unset($this->bindValues[$column]);
+        $hlds[] = $value->getExpression();
+      } else {
+        $hlds[] = "@{$column}@";
+      }
+    }
+    
     $sql .= implode(", ", $cols) . ") VALUES(" . implode(", ", $hlds) . ")";
     return $sql;
   }
@@ -378,7 +410,12 @@ abstract class Sabel_DB_Statement extends Sabel_Object
   {
     $updates = array();
     foreach ($this->values as $column => $value) {
-      $updates[] = $this->quoteIdentifier($column) . " = @{$column}@";
+      if ($value instanceof Sabel_DB_Statement_Expression) {
+        unset($this->bindValues[$column]);
+        $updates[] = $this->quoteIdentifier($column) . " = " . $value->getExpression();
+      } else {
+        $updates[] = $this->quoteIdentifier($column) . " = @{$column}@";
+      }
     }
     
     $tblName = $this->quoteIdentifier($this->table);
@@ -427,6 +464,32 @@ abstract class Sabel_DB_Statement extends Sabel_Object
     }
   }
   
+  /**
+   * @param string $str
+   *
+   * @return string
+   */
+  public function escapeString($str)
+  {
+    $escaped = $this->escape(array($str));
+    return $escaped[0];
+  }
+  
+  public function quoteIdentifier($arg)
+  {
+    if (is_array($arg)) {
+      foreach ($arg as &$v) {
+        $v = '"' . $v . '"';
+      }
+      return $arg;
+    } elseif (is_string($arg)) {
+      return '"' . $arg . '"';
+    } else {
+      $message = __METHOD__ . "() argument must be a string or an array.";
+      throw new Sabel_Exception_InvalidArgument($message);
+    }
+  }
+  
   protected function quoteIdentifierForOrderString($orderBy)
   {
     $results = array();
