@@ -16,19 +16,35 @@ class Sabel_DB_Ibase_Statement extends Sabel_DB_Statement
     $this->driver = $driver;
   }
   
-  public function escape(array $values)
+  public function values(array $values)
   {
-    foreach ($values as &$val) {
-      if (is_bool($val)) {
-        $val = ($val) ? 1 : 0;
-      } elseif (is_string($val)) {
-        $val = "'" . ibase_escape_string($val) . "'";
+    $columns = $this->metadata->getColumns();
+    foreach ($values as $k => &$v) {
+      if (isset($columns[$k]) && $columns[$k]->isBinary()) {
+        $v = $this->createBlob($v);
       }
     }
     
+    $this->values = $values;
+    $this->appendBindValues($values);
+    
+    return $this;
+  }
+  
+  public function escape(array $values)
+  {
+    foreach ($values as &$val) {
+      if (is_bool($val)) $val = ($val) ? 1 : 0;
+    }
+    
     return $values;
   }
   
+  public function createBlob($binary)
+  {
+    return new Sabel_DB_Ibase_Blob($binary);
+  }
+  
   protected function createSelectSql()
   {
     $sql = "SELECT ";
@@ -60,9 +76,8 @@ class Sabel_DB_Ibase_Statement extends Sabel_DB_Statement
     if (($column = $this->seqColumn) !== null) {
       $seqName = strtoupper("{$this->table}_{$column}_seq");
       $rows = $this->driver->execute("SELECT GEN_ID({$seqName}, 1) AS id FROM RDB\$DATABASE");
-      $id = $rows[0]["id"];
-      $values = array_merge($this->values, array($column => $id));
-      $this->values($values);
+      $this->values[$column] = $id = $rows[0]["id"];
+      $this->appendBindValues(array($column => $id));
       $this->driver->setLastInsertId($id);
     }
     
@@ -79,7 +94,7 @@ class Sabel_DB_Ibase_Statement extends Sabel_DB_Statement
     } elseif (is_string($arg)) {
       return '"' . strtoupper($arg) . '"';
     } else {
-      $message = "argument must be a string or an array.";
+      $message = __METHOD__ . "() argument must be a string or an array.";
       throw new Sabel_Exception_InvalidArgument($message);
     }
   }
@@ -96,16 +111,3 @@ class Sabel_DB_Ibase_Statement extends Sabel_DB_Statement
     return $sql;
   }
 }
-
-if (ini_get("magic_quotes_sybase") === "1") {
-  function ibase_escape_string($val)
-  {
-    return $val;
-  }
-}
-else {
-  function ibase_escape_string($val)
-  {
-    return str_replace("'", "''", $val);
-  }
-}
