@@ -30,4 +30,10 @@ class Sabel_DB_Mysqli_Statement extends Sabel_DB_Mysql_Statement
     
     return $values;
   }
+  
+  public function createBlob($binary)
+  {
+    $conn = $this->driver->getConnection();
+    return new Sabel_DB_Mysqli_Blob($conn, $binary);
+  }
 }
