@@ -14,6 +14,13 @@ class Sabel_Response_Header_Cli
   public function output(Sabel_Response $response)
   {
     $headers = array();
+    $httpVersion = "HTTP/1.0";
+    
+    $headers[] = $httpVersion . " " . $response->getStatus()->toString();
+    
+    if ($response->isRedirected()) {
+      $headers[] = "Location: " . $response->getLocation();
+    }
     
     if ($response->hasHeaders()) {
       foreach ($response->getHeaders() as $message => $value) {
@@ -21,22 +28,6 @@ class Sabel_Response_Header_Cli
       }
     }
     
-    if ($response->getLocation()) {
-      l("redirect: " . var_export($response->getLocation(), 1));
-    }
-    
-    if ($response->isRedirected()) {
-      $headers[] = "Location: " . $response->getLocation();
-    } elseif ($response->isNotFound()) {
-      $headers[] = "HTTP/1.0 404 Not Found";
-    } elseif ($response->isForbidden()) {
-      $headers[] = "HTTP/1.0 403 Forbidden";
-    } elseif ($response->isServerError()) {
-      $headers[] = "HTTP/1.0 500 Internal Server Error";
-    } elseif ($response->isNotModified()) {
-      $headers[] = "HTTP/1.0 304 Not Modified";
-    }
-    
     return $headers;
   }
 }
