@@ -12,29 +12,17 @@
  */
 abstract class Sabel_View_Location extends Sabel_Object
 {
-  protected $baseDir = "";
-  protected $viewDir = "";
-  protected $name    = "";
+  protected $viewDirPath = "";
+  protected $name        = "";
   
   abstract public function isValid();
   abstract public function getContents();
   abstract public function create($body = "");
   abstract public function delete();
   
-  public function __construct($viewDir, $baseDir = "")
+  public function __construct($viewDirPath)
   {
-    if ($baseDir === "") {
-      if (defined("MODULES_DIR_PATH")) {
-        $this->baseDir = MODULES_DIR_PATH;
-      } else {
-        $message = "must define MODULES_DIR_PATH for base directory.";
-        throw new Sabel_Exception_Runtime(__METHOD__ . "() $message");
-      }
-    } else {
-      $this->baseDir = $baseDir;
-    }
-    
-    $this->viewDir = $viewDir;
+    $this->viewDirPath = $viewDirPath;
   }
   
   public function name($name = null)
@@ -51,6 +39,6 @@ abstract class Sabel_View_Location extends Sabel_Object
   
   public function getPath()
   {
-    return $this->baseDir . DS . $this->viewDir . $this->name;
+    return MODULES_DIR_PATH . DS . $this->viewDirPath . $this->name;
   }
 }
